Attribute VB_Name = "Module1"
Public Declare Sub Sleep Lib "kernel32" (ByVal dwMilliseconds As Long)

Sub main()

  Rem #########################################
  Rem
  Rem    Using NI-VISA library visa32.dll
  Rem
  Rem    Set sample count 5 configuration and
  Rem    read the trigger
  Rem
  Rem #########################################
  
  Dim stat  As ViStatus
  Dim dfltRM As ViSession
  Dim sesn As ViSession
  Dim fList As ViFindList
  Dim desc As String * VI_FIND_BUFLEN
  Dim nList As Long
  Dim ret As Long
  Dim readin As String * 128
  Dim i As Integer      ' Array index
  
  stat = viOpenDefaultRM(dfltRM)
  If (stat < VI_SUCCESS) Then
    'Rem Error initializing VISA ... exiting
    MsgBox "Could not open a session to the VISA Resource Manager!", vbExclamation, "Multimeter device test"
    Exit Sub
  End If
  
  Rem Open a session to each and determine if it matches
  stat = viOpen(dfltRM, "ASRL1::INSTR", VI_NULL, VI_NULL, sesn)
  If (stat < VI_SUCCESS) Then
      MsgBox "Open device failed.", vbExclamation, "Multimeter device test"
      stat = viClose(fList)
      Exit Sub
  End If
  'Set the timeout to 5 seconds (5000 milliseconds)
  stat = viSetAttribute(sesn, VI_ATTR_TMO_VALUE, 5000)
  'Set the baud rate to 4800 (default is 9600).
  stat = viSetAttribute(sesn, VI_ATTR_ASRL_BAUD, 4800)
  'Set the number of data bits contained in each frame (from 5 to 8).
  'The data bits for  each frame are located in the low-order bits of
  'every byte stored in memory.
  stat = viSetAttribute(sesn, VI_ATTR_ASRL_DATA_BITS, 8)
  ' Specify parity. Options:
  ' VI_ASRL_PAR_NONE  - No parity bit exists,
  ' VI_ASRL_PAR_ODD   - Odd parity should be used,
  ' VI_ASRL_PAR_EVEN  - Even parity should be used,
  ' VI_ASRL_PAR_MARK  - Parity bit exists and is always 1,
  ' VI_ASRL_PAR_SPACE - Parity bit exists and is always 0.
  stat = viSetAttribute(sesn, VI_ATTR_ASRL_PARITY, VI_ASRL_PAR_NONE)
  ' Specify stop bit. Options:
  ' VI_ASRL_STOP_ONE   - 1 stop bit is used per frame,
  ' VI_ASRL_STOP_ONE_5 - 1.5 stop bits are used per frame,
  ' VI_ASRL_STOP_TWO   - 2 stop bits are used per frame.
  stat = viSetAttribute(sesn, VI_ATTR_ASRL_STOP_BITS, VI_ASRL_STOP_ONE)
  ' Specify that the read operation should terminate when a termination
  ' character is received.
  stat = viSetAttribute(sesn, VI_ATTR_TERMCHAR_EN, VI_TRUE)
              
  Rem send reset command '*RST' -- reset 2100
  stat = viWrite(sesn, "*RST" & vbLf, 5, ret)
  If (stat < VI_SUCCESS) Then
    MsgBox "System command error. (*RST)", vbExclamation, "Multimeter device test"
    stat = viClose(fList)
    Exit Sub
  End If
  Rem send Clear command '*CLS'-- Clear 2100 status register
  stat = viWrite(sesn, "*CLS" & vbLf, 5, ret)
  If (stat < VI_SUCCESS) Then
    MsgBox "System command error. (*CLS)", vbExclamation, "Multimeter device test"
    stat = viClose(fList)
    Exit Sub
  End If
  
  Rem send command -- Select dBm function
  stat = viWrite(sesn, "CONF:VOLT:DC" & vbLf, 14, ret)
  If (stat < VI_SUCCESS) Then
    MsgBox "System command error.", vbExclamation, "Multimeter device test"
    stat = viClose(fList)
    Exit Sub
  End If
  
  Rem send command -- Enable math
  stat = viWrite(sesn, "SAMP:COUNT 5" & vbLf, 13, ret)
  If (stat < VI_SUCCESS) Then
    MsgBox "System command error.", vbExclamation, "Multimeter device test"
    stat = viClose(fList)
    Exit Sub
  End If
  
  Rem send command -- Take readings
  stat = viWrite(sesn, "READ?" & vbLf, 6, ret)
  If (stat < VI_SUCCESS) Then
    MsgBox "System command error.", vbExclamation, "Multimeter device test"
    stat = viClose(fList)
    Exit Sub
  End If

  Sleep (3000)  ' wait for math processing
    
  Rem fetch the measure data
  stat = viRead(sesn, readin, 128, ret)
  If (stat < VI_SUCCESS) Then
    MsgBox "Read in data error.", vbExclamation, "Multimeter device test"
    stat = viClose(fList)
    Exit Sub
  End If
   
  Rem set to local mode
  stat = viWrite(sesn, "system:local" & vbLf, 13, ret)
  If (stat < VI_SUCCESS) Then
    MsgBox "System command error. (system:local)", vbExclamation, "Multimeter device test"
    stat = viClose(fList)
    Exit Sub
  End If

  stat = viClose(sesn)
  stat = viClose(fList)
  stat = viClose(dfltRM)

  Rem print out the 5 times samples reading
  For i = 0 To (5 - 1)
    Debug.Print "Rdgs = "; Mid(readin, i * 16 + 1, 15)
  Next

  MsgBox "End of Job."

End Sub
